// Copyright 2022 schukai GmbH
// SPDX-License-Identifier: AGPL-3.0

package xflags

import (
	"github.com/stretchr/testify/assert"
	"testing"
)

type ConfigStruct6Sub1 struct {
	Command3Flag1 bool
}

type ConfigStruct6 struct {
	ValGlobal1       bool
	ValGlobal2       bool
	ValCommand1Flag1 bool
	ValCommand1Flag2 bool
	ValSub           ConfigStruct6Sub1
}

func TestFlagCopyToShadow(t *testing.T) {

	c := ConfigStruct6{}
	c.ValSub.Command3Flag1 = true

	settings := New("test", testExecutionStruct{})
	assert.NotNil(t, settings)

	settings.SetProxy(&c)
	assert.False(t, settings.HasErrors())

	settings.Parse([]string{"-a", "command1", "-d"})

	assert.True(t, c.ValGlobal1)
	assert.True(t, c.ValCommand1Flag2)

}

func (s *ConfigStruct6) Copy(m map[string]any) {
	SetValueUsingPath(s, "ValGlobal1", (m["Global1"]))
	SetValueUsingPath(s, "ValCommand1Flag2", (m["Command1.Command1Flag2"]))
}

func TestCopyable(t *testing.T) {

	c := ConfigStruct6{}
	c.ValSub.Command3Flag1 = true

	settings := execute(testExecutionStruct{}, &c, "test", []string{"-a", "command3"})

	assert.False(t, settings.HasErrors())
}
